@@ -1,4 +1,4 @@
-# Copyright 2019 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2021 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -27,8 +27,8 @@ from asreview.models.feature_extraction.base import BaseFeatureExtraction
 def _check_gensim():
     if not GENSIM_AVAILABLE:
         raise ImportError(
-            "Install gensim package (`pip install gensim`) to use"
-            " 'Doc2Vec' model.")
+            "Install gensim package to use"
+            " Doc2Vec.")
 
 
 def _train_model(corpus, *args, **kwargs):
@@ -48,9 +48,9 @@ def _transform_text(model, corpus):
 
 
 class Doc2Vec(BaseFeatureExtraction):
-    """Base class for doc2vec feature extraction.
+    """Doc2Vec feature extraction technique.
 
-    Feature extraction method provided by the `gensim
+    Feature extraction technique provided by the `gensim
     <https://radimrehurek.com/gensim/>`__ package. It takes relatively long to
     create a feature matrix with this method. However, this only has to be
     done once per simulation/review. The upside of this method is the
@@ -59,7 +59,7 @@ class Doc2Vec(BaseFeatureExtraction):
 
     .. note::
 
-        This feature extraction algorithm requires ``gensim`` to be installed.
+        This feature extraction technique requires ``gensim`` to be installed.
         Use ``pip install gensim`` or install all optional ASReview
         dependencies with ``pip install asreview[all]``
 
@@ -90,6 +90,7 @@ class Doc2Vec(BaseFeatureExtraction):
     """
 
     name = "doc2vec"
+    label = "Doc2Vec"
 
     def __init__(self,
                  *args,
