@@ -1,4 +1,4 @@
-# Copyright 2019 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2020 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +14,8 @@
 
 from asreview.models.query.max import MaxQuery
 from asreview.models.query.mixed import MixedQuery
+from asreview.models.query.mixed import MaxRandomQuery
+from asreview.models.query.mixed import MaxUncertaintyQuery
 from asreview.models.query.uncertainty import UncertaintyQuery
 from asreview.models.query.random import RandomQuery
 from asreview.models.query.cluster import ClusterQuery
