@@ -1,4 +1,4 @@
-# Copyright 2019 The ASReview Authors. All Rights Reserved.
+# Copyright 2019-2021 The ASReview Authors. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,7 +20,7 @@ from asreview.utils import get_random_state
 
 
 class RandomQuery(NotProbaQueryStrategy):
-    """Random sampling query strategy.
+    """Random query strategy.
 
     Randomly select samples with no regard to model assigned probabilities.
 
@@ -30,6 +30,7 @@ class RandomQuery(NotProbaQueryStrategy):
 
     """
     name = "random"
+    label = "Random"
 
     def __init__(self, random_state=None):
         super(RandomQuery, self).__init__()
