@@ -1,3 +1,17 @@
+# Copyright 2019-2020 The ASReview Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import logging
 import os
 import webbrowser
@@ -8,11 +22,13 @@ from flask import send_from_directory
 from flask.json import jsonify
 from flask.templating import render_template
 from flask_cors import CORS
+from gevent.pywsgi import WSGIServer
 from werkzeug.exceptions import InternalServerError
 
 from asreview import __version__ as asreview_version
 from asreview.entry_points.lab import _lab_parser
 from asreview.webapp import api
+from asreview.webapp.utils.misc import check_port_in_use
 from asreview.webapp.utils.project import clean_project_tmp_files
 from asreview.webapp.utils.project import clean_all_project_tmp_files
 
@@ -23,12 +39,32 @@ else:
     logging.basicConfig(level=logging.INFO)
 
 
-def _url(host, port):
-    return "http://{host}:{port}/".format(host=host, port=port)
+def _url(host, port, protocol):
+    """Create url from host and port."""
+    return f"{protocol}{host}:{port}/"
 
 
-def _open_browser(host, port):
-    webbrowser.open_new(_url(host, port))
+def _open_browser(host, port, protocol, no_browser):
+    """Open ASReview in browser if flag is set.
+
+    Otherwise, it displays an alert to copy and paste the url
+    at which ASReview is currently served.
+    """
+    if no_browser:
+        print(
+            "\nTo access ASReview LAB, copy and paste "
+            "this url in a browser "
+            f"{_url(host, port, protocol)}\n"
+        )
+        return
+
+    start_url = _url(host, port, protocol)
+    Timer(1, lambda: webbrowser.open_new(start_url)).start()
+    print(
+        f"Start browser at {start_url}"
+        "\n\n\n\nIf your browser doesn't open. "
+        f"Please navigate to '{start_url}'\n\n\n\n"
+    )
 
 
 def create_app(**kwargs):
@@ -82,8 +118,7 @@ def create_app(**kwargs):
 
     @app.route('/boot', methods=["GET"])
     def api_boot():
-        """Get the boot info"""
-
+        """Get the boot info."""
         if os.environ.get("FLASK_ENV", None) == "development":
             status = "development"
         else:
@@ -113,35 +148,65 @@ def main(argv):
     parser = _lab_parser(prog="lab")
     args = parser.parse_args(argv)
 
-    # clean all projects
-    if args.clean_all_projects:
-        clean_all_project_tmp_files()
-        return
-
-    # clean project by project_id
-    if args.clean_project is not None:
-        clean_project_tmp_files(args.clean_project)
-        return
-
-    # shortcuts for host and port
-    host = args.ip
-    port = args.port
-
-    def _internal_open_webbrowser():
-        _open_browser(host, port)
-
-    # open webbrowser if not in flask development mode
-    if os.environ.get('FLASK_ENV', "") != "development":
-        Timer(1, _internal_open_webbrowser).start()
-
-    print(
-        "\n\n\n\nIf your browser doesn't open. "
-        "Please navigate to '{url}'\n\n\n\n".format(url=_url(host, port)))
-
     app = create_app(
         embedding_fp=args.embedding_fp,
         config_file=args.config_file,
         seed=args.seed
     )
     app.config['PROPAGATE_EXCEPTIONS'] = False
-    app.run(host=host, port=port)
+
+    # ssl certificate, key and protocol
+    certfile = args.certfile
+    keyfile = args.keyfile
+    ssl_context = None
+    if certfile and keyfile:
+        protocol = "https://"
+        ssl_context = (certfile, keyfile)
+    else:
+        protocol = "http://"
+
+    # clean all projects
+    if args.clean_all_projects:
+        print("Cleaning all project files.")
+        clean_all_project_tmp_files()
+        print("Done")
+        return
+
+    # clean project by project_id
+    if args.clean_project is not None:
+        print(f"Cleaning project file '{args.clean_project}'.")
+        clean_project_tmp_files(args.clean_project)
+        print("Done")
+        return
+
+    flask_dev = os.environ.get('FLASK_ENV', "") == "development"
+    host = args.ip
+    port = args.port
+    port_retries = args.port_retries
+    # if port is already taken find another one
+    if not os.environ.get('FLASK_ENV', "") == "development":
+        original_port = port
+        while check_port_in_use(host, port) is True:
+            old_port = port
+            port = int(port) + 1
+            if port - original_port >= port_retries:
+                raise ConnectionError(
+                    "Could not find an available port \n"
+                    "to launch ASReview LAB. Last port \n"
+                    f"was {str(port)}"
+                )
+            print(
+                f"Port {old_port} is in use.\n* Trying to start at {port}"
+            )
+
+    # open webbrowser if not in flask development mode
+    if flask_dev is False:
+        _open_browser(host, port, protocol, args.no_browser)
+
+    # run app in flask mode only if flask_env == development is True
+    if flask_dev is True:
+        app.run(host=host, port=port, ssl_context=ssl_context)
+    else:
+        ssl_args = {'keyfile': keyfile, 'certfile': certfile} if ssl_context else {}
+        server = WSGIServer((host, port), app, **ssl_args)
+        server.serve_forever()
